@@ -20,12 +20,13 @@ class build_pot(Command):
     #   - long name,
     #   - short name (None if no short name),
     #   - help string.
-    user_options = [('build-dir=', 'd', 'Directory to put POT file'),
-                    ('output=', 'o', 'POT filename'),
-                    ('lang=', None,
-                     'Comma-separated list of languages to update po-files'),
-                    ('no-lang', 'N', "Don't update po-files"),
-                    ('english', 'E', 'Regenerate English PO file')]
+    user_options = [
+        ('build-dir=', 'd', 'Directory to put POT file'),
+        ('output=', 'o', 'POT filename'),
+        ('lang=', None, 'Comma-separated list of languages to update po-files'),
+        ('no-lang', 'N', "Don't update po-files"),
+        ('english', 'E', 'Regenerate English PO file'),
+    ]
     user_options = build_util.stringify_options(user_options)
     boolean_options = build_util.stringify_list(['no-lang', 'english'])
 
@@ -45,8 +46,8 @@ class build_pot(Command):
             self.lang = [i.strip() for i in self.lang.split(',') if i.strip()]
         if self.lang and self.no_lang:
             raise DistutilsOptionError(
-                "You can't use options "
-                "--lang=XXX and --no-lang in the same time.")
+                "You can't use options " "--lang=XXX and --no-lang in the same time."
+            )
 
     def run(self):
         """Run xgettext for project sources"""
@@ -70,8 +71,10 @@ class build_pot(Command):
             '--no-location',
             '--omit-header',
             '--sort-output',
-            '--output-dir', self.build_dir,
-            '--output', self.output,
+            '--output-dir',
+            self.build_dir,
+            '--output',
+            self.output,
         ]
         cmd.extend(glob.glob('bin/git-*'))
         cmd.extend(glob.glob('share/git-cola/bin/git-*'))
@@ -87,30 +90,41 @@ class build_pot(Command):
                 en_po = prj_name + '-' + 'en.po'
             else:
                 en_po = 'en.po'
-            self.spawn([
-                'msginit',
-                '--no-translator',
-                '--locale', 'en',
-                '--input', os.path.join(self.build_dir, self.output),
-                '--output-file', os.path.join(self.build_dir, en_po)])
+            self.spawn(
+                [
+                    'msginit',
+                    '--no-translator',
+                    '--locale',
+                    'en',
+                    '--input',
+                    os.path.join(self.build_dir, self.output),
+                    '--output-file',
+                    os.path.join(self.build_dir, en_po),
+                ]
+            )
         # search and update all po-files
         if self.no_lang:
             return
         for po in glob.glob(os.path.join(self.build_dir, '*.po')):
             if self.lang is not None:
                 po_lang = os.path.splitext(os.path.basename(po))[0]
-                if prj_name and po_lang.startswith(prj_name+'-'):
+                if prj_name and po_lang.startswith(prj_name + '-'):
                     po_lang = po_lang[5:]
                 if po_lang not in self.lang:
                     continue
             new_po = po + '.new'
-            self.spawn([
-                'msgmerge',
-                '--no-location',
-                '--no-wrap',
-                '--sort-output',
-                '--output-file', new_po,
-                po, fullname])
+            self.spawn(
+                [
+                    'msgmerge',
+                    '--no-location',
+                    '--no-wrap',
+                    '--sort-output',
+                    '--output-file',
+                    new_po,
+                    po,
+                    fullname,
+                ]
+            )
             # force LF line-endings
             log.info('%s --> %s' % (new_po, po))
             _force_LF(new_po, po)
